package widebase.rpc

import msgpack.rpcx.auth.AuthMap

import vario.data.Datatype
import vario.filter.StreamFilter

import widebase.db.Database
import widebase.rpc.handler.ServerHandler

/** RPC Server.
 *
 * @param dbi database interface
 * @param jaas entry name
 * @param auths procedure based authorizations
 * @param zipped self-explenatory
 *
 * @author myst3r10n
 */
class Server(
  dbi: Database,
  jaas: String,
  auths: AuthMap,
  zipped: String = "")
  extends msgpack.rpcx.Server {

  /** Alternative constructor.
   *
   * @param handler alternative
   */
  def this(handler: ServerHandler) = {

    this(null, null, null, null)

    this.handler = handler

  }

  if(dbi != null) {

    val inFileFilter =
      if(zipped.contains("rf"))
        StreamFilter.Gzip
      else
        StreamFilter.None

    val outFileFilter =
      if(zipped.contains("wf"))
        StreamFilter.Gzip
      else
        StreamFilter.None

    val inSocketFilter =
      if(zipped.contains("rs"))
        StreamFilter.Gzip
      else
        StreamFilter.None

    val outSocketFilter =
      if(zipped.contains("ws"))
        StreamFilter.Gzip
      else
        StreamFilter.None

    handler = new ServerHandler(
        dbi,
        this,
        jaas,
        auths,
        inFileFilter,
        outFileFilter,
        inSocketFilter,
        outSocketFilter)

  }
}

