package widebase

import msgpack.rpcx.auth.AuthMap

import widebase.db.Database
import widebase.rpc.handler.ServerHandler

/** RPC package
 *
 * @author myst3r10n
 */
package object rpc {

  /** Create [[widebase.rpc.Client]] instance.
   *
   * @param host of server
   * @param port of server
   *
   * @return instance of [[widebase.rpc.Client]]
   */
  def client(host: String, port: Int) = new Client(host, port)

  /** Create [[widebase.rpc.SessionPool]] instance. */
  def pool = new SessionPool

  /** Create [[widebase.rpc.Server]] instance.
   *
   * @param handler alternative
   *
   * @return instance of [[widebase.rpc.Server]]
   */
  def server(handler: ServerHandler) = new Server(handler)

  /** Create [[widebase.rpc.Server]] instance.
   *
   * @param dbi database interface
   * @param jaas entry name
   * @param auths procedure based authorizations
   * @param zipped self-explenatory
   *
   * @return instance of [[widebase.rpc.Server]]
   */
  def server(
    dbi: Database,
    jaas: String,
    auths: AuthMap,
    zipped: String = "") =
    new Server(dbi, jaas, auths, zipped)

}

